@@ -23,7 +23,7 @@
 modname = 'cubicweb_saml'
 distname = 'cubicweb-saml'
 
-numversion = (0, 4, 0)
+numversion = (0, 5, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -33,7 +33,7 @@ description = 'SAML2 authentifier'
 web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
 __depends__ = {
-    'cubicweb': ">= 3.30.0",
+    'cubicweb': ">= 3.30.0, < 3.34.0",
     'logilab-common': '>= 1.4.0',
     'pyramid': '>= 1.10.4',
     'pysaml2': '>= 5.0.0',
